==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'No hi ha banda sonora', # MODIF
	'aucun_document' => 'Cap document',
	'aucun_file' => 'Cap document',
	'aucun_image' => 'Cap imatge',
	'aucun_video' => 'Cap seqüència',
	'aucune_utilisation' => 'Aquest document no s’ha utilitzat',
	'aucune_vignette' => 'Cap miniatura',

	// B
	'bouton_ajouter_document' => 'Afegir un document',
	'bouton_ajouter_image' => 'Afegir una imatge',
	'bouton_ajouter_image_document' => 'Afegir una imatge o un document',
	'bouton_attacher_document' => 'Lligar',
	'bouton_copier_local' => 'Copiar al lloc',
	'bouton_download_depuis' => 'des de:',
	'bouton_download_local' => 'el meu ordinador',
	'bouton_download_par_ftp' => 'el servidor',
	'bouton_download_par_mediatheque' => 'la mediateca', # MODIF
	'bouton_download_sur_le_web' => 'Internet',
	'bouton_enlever_document' => 'Separar', # MODIF
	'bouton_enlever_supprimer_document' => 'Suprimir',
	'bouton_enlever_supprimer_document_confirmation' => 'Esteu segur que voleu suprimir el document?', # MODIF
	'bouton_modifier_document' => 'Modificar',
	'bouton_parcourir' => 'Examinar...', # MODIF
	'bouton_refresh_document' => 'Actualitzar el document', # MODIF
	'bouton_remplacer_document' => 'Substituir aquest document',
	'bouton_remplacer_image' => 'Substituir aquesta imatge',
	'bouton_remplacer_image_document' => 'Substituir per una imatge o un document',
	'bouton_supprimer' => 'Suprimir',
	'bouton_supprimer_tous_orphelins' => 'Suprimir tots els orfes',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Esteu segur de voler suprimir @nb@ orfes?', # MODIF
	'bouton_upload' => 'Descarregar', # MODIF

	// D
	'des_audios' => '@nb@ bandes sonores', # MODIF
	'des_documents' => '@nb@ documents',
	'des_files' => '@nb@ documents',
	'des_images' => '@nb@ imatges',
	'des_utilisations' => '@nb@ usos',
	'des_videos' => '@nb@ seqüències',
	'descriptif' => 'Descripció',
	'document_attache_succes' => 'El document s’ha afegit correctament',
	'document_copie_locale_succes' => 'El fitxer s’ha copiat al lloc correctament',
	'document_installe_succes' => 'El fitxer s’ha carregat correctament',
	'document_vu' => 'Inserir al text',
	'documents' => 'Mediateca', # MODIF
	'documents_brises' => 'Trencats',
	'documents_distants' => 'Distants',
	'documents_locaux' => 'Locals',
	'documents_non_publies' => 'No publicats',
	'documents_orphelins' => 'Inutilitzats',
	'documents_publies' => 'Publicats',
	'documents_tous' => 'Tots',
	'double_clic_inserer_doc' => 'Feu un doble clic per inserir aquesta drecera en el text',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol del document:',
	'entree_titre_image' => 'Títol de la imatge:',
	'erreur_aucun_document' => 'Aquest document no existeix a la mediateca', # MODIF
	'erreur_aucun_fichier' => 'No s’ha trobat cap fitxer',
	'erreur_chemin_distant' => 'El fitxer distant @nom@ no s’ha pogut trobar',
	'erreur_chemin_ftp' => 'El fitxer indicat no s’ha trobat al servidor',
	'erreur_copie_fichier' => 'Impossible copiar el fitxer @nom@',
	'erreur_dossier_tmp_manquant' => 'Falta una carpeta temporal per descarregar els fitxers ',
	'erreur_ecriture_fichier' => 'Error durant l’escriptura del fitxer al disc',

	// I
	'image_tourner_180' => 'Girar 180°',
	'image_tourner_droite' => 'Girar 90° cap a la dreta',
	'image_tourner_gauche' => 'Girar 90° cap a l’esquerre',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Aquest document no està disponible',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusió directa:',
	'info_inclusion_vignette' => 'Inclusió de la icona:',
	'info_installer_tous_documents' => 'Instal·lar tots els documents',
	'info_logo_max_taille' => 'Els logotips han de fer obligatòriament menys de @maxi@ (aquest fitxer fa @actuel@).',
	'info_portfolio' => 'Carpeta',
	'info_referencer_doc_distant' => 'Referenciar un document a Internet :',
	'info_telecharger' => 'Carregar des del vostre ordinador:',
	'item_autoriser_selectionner_date_en_ligne' => 'Permitir la modificación de la fecha de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La data dels documents és la de quan han estat afegits al lloc',

	// T
	'texte_documents_joints' => 'Es pot permetre afegir documents (fitxers ofimàtics, imatges, multimèdia, etc.) als articles i/o a les seccions. Aquests fitxers poden estar referenciats a dins l’article, o mostrats separadament.</p>', # MODIF
	'texte_documents_joints_2' => 'Aquesta regla no impideix pas l’inserció d’imatges directament als articles.', # MODIF
	'titre_documents_joints' => 'Documents adjunts',
	'tout_dossier_upload' => 'Tot el directori @upload@',

	// U
	'upload_fichier_zip' => 'Fitxer ZIP',
	'upload_fichier_zip_texte' => 'El fitxer que voleu instal·lar és un fitxer Zip.',
	'upload_fichier_zip_texte2' => 'El fitxer pot ser:',
	'upload_limit' => 'El fitxer és massa gran pel servidor; la   mida màxima autoritzada en <i>upload</i> és de @max@.',
	'upload_zip_conserver' => 'Conservar l’arxiu desprès de l’extracció', # MODIF
	'upload_zip_decompacter' => 'descomprimit i cada element que conté instal·lat en el lloc Web. Els fitxers que llavors seran instal·lat en el lloc Web són:',
	'upload_zip_telquel' => 'instal·lat tal qual, com a arxiu comprimit Zip;',
	'upload_zip_titrer' => 'Titular segons el nom dels fitxers'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'No hi ha banda sonora', # MODIF
	'aucun_document' => 'Cap document',
	'aucun_file' => 'Cap document',
	'aucun_image' => 'Cap imatge',
	'aucun_video' => 'Cap seqüència',
	'aucune_utilisation' => 'Aquest document no s’ha utilitzat',
	'aucune_vignette' => 'Cap miniatura',

	// B
	'bouton_ajouter_document' => 'Afegir un document',
	'bouton_ajouter_image' => 'Afegir una imatge',
	'bouton_ajouter_image_document' => 'Afegir una imatge o un document',
	'bouton_attacher_document' => 'Lligar',
	'bouton_copier_local' => 'Copiar al lloc',
	'bouton_download_depuis' => 'des de:',
	'bouton_download_local' => 'el meu ordinador',
	'bouton_download_par_ftp' => 'el servidor',
	'bouton_download_par_mediatheque' => 'la mediateca', # MODIF
	'bouton_download_sur_le_web' => 'Internet',
	'bouton_enlever_document' => 'Separar', # MODIF
	'bouton_enlever_supprimer_document' => 'Suprimir',
	'bouton_enlever_supprimer_document_confirmation' => 'Esteu segur que voleu suprimir el document?', # MODIF
	'bouton_modifier_document' => 'Modificar',
	'bouton_parcourir' => 'Examinar...', # MODIF
	'bouton_refresh_document' => 'Actualitzar el document', # MODIF
	'bouton_remplacer_document' => 'Substituir aquest document',
	'bouton_remplacer_image' => 'Substituir aquesta imatge',
	'bouton_remplacer_image_document' => 'Substituir per una imatge o un document',
	'bouton_supprimer' => 'Suprimir',
	'bouton_supprimer_tous_orphelins' => 'Suprimir tots els orfes', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Esteu segur de voler suprimir @nb@ orfes?', # MODIF
	'bouton_upload' => 'Descarregar', # MODIF

	// D
	'des_audios' => '@nb@ bandes sonores', # MODIF
	'des_documents' => '@nb@ documents',
	'des_files' => '@nb@ documents',
	'des_images' => '@nb@ imatges',
	'des_utilisations' => '@nb@ usos',
	'des_videos' => '@nb@ seqüències',
	'descriptif' => 'Descripció',
	'document_attache_succes' => 'El document s’ha afegit correctament',
	'document_copie_locale_succes' => 'El fitxer s’ha copiat al lloc correctament',
	'document_installe_succes' => 'El fitxer s’ha carregat correctament',
	'document_vu' => 'Inserir al text',
	'documents' => 'Mediateca', # MODIF
	'documents_brises' => 'Trencats',
	'documents_distants' => 'Distants',
	'documents_locaux' => 'Locals',
	'documents_non_publies' => 'No publicats',
	'documents_orphelins' => 'Inutilitzats',
	'documents_publies' => 'Publicats',
	'documents_tous' => 'Tots',
	'double_clic_inserer_doc' => 'Feu un doble clic per inserir aquesta drecera en el text',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol del document:',
	'entree_titre_image' => 'Títol de la imatge:',
	'erreur_aucun_document' => 'Aquest document no existeix a la mediateca', # MODIF
	'erreur_aucun_fichier' => 'No s’ha trobat cap fitxer',
	'erreur_chemin_distant' => 'El fitxer distant @nom@ no s’ha pogut trobar',
	'erreur_chemin_ftp' => 'El fitxer indicat no s’ha trobat al servidor',
	'erreur_copie_fichier' => 'Impossible copiar el fitxer @nom@',
	'erreur_dossier_tmp_manquant' => 'Falta una carpeta temporal per descarregar els fitxers ',
	'erreur_ecriture_fichier' => 'Error durant l’escriptura del fitxer al disc',

	// I
	'image_tourner_180' => 'Girar 180°',
	'image_tourner_droite' => 'Girar 90° cap a la dreta',
	'image_tourner_gauche' => 'Girar 90° cap a l’esquerre',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Aquest document no està disponible',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusió directa:',
	'info_inclusion_vignette' => 'Inclusió de la icona:',
	'info_installer_tous_documents' => 'Instal·lar tots els documents',
	'info_logo_max_taille' => 'Els logotips han de fer obligatòriament menys de @maxi@ (aquest fitxer fa @actuel@).',
	'info_portfolio' => 'Carpeta',
	'info_referencer_doc_distant' => 'Referenciar un document a Internet :',
	'info_telecharger' => 'Carregar des del vostre ordinador:',
	'item_autoriser_selectionner_date_en_ligne' => 'Permitir la modificación de la fecha de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La data dels documents és la de quan han estat afegits al lloc',

	// T
	'texte_documents_joints' => 'Es pot permetre afegir documents (fitxers ofimàtics, imatges, multimèdia, etc.) als articles i/o a les seccions. Aquests fitxers poden estar referenciats a dins l’article, o mostrats separadament.</p>', # MODIF
	'texte_documents_joints_2' => 'Aquesta regla no impideix pas l’inserció d’imatges directament als articles.', # MODIF
	'titre_documents_joints' => 'Documents adjunts',
	'tout_dossier_upload' => 'Tot el directori @upload@',

	// U
	'upload_fichier_zip' => 'Fitxer ZIP',
	'upload_fichier_zip_texte' => 'El fitxer que voleu instal·lar és un fitxer Zip.',
	'upload_fichier_zip_texte2' => 'El fitxer pot ser:',
	'upload_limit' => 'El fitxer és massa gran pel servidor; la   mida màxima autoritzada en <i>upload</i> és de @max@.',
	'upload_zip_conserver' => 'Conservar l’arxiu desprès de l’extracció', # MODIF
	'upload_zip_decompacter' => 'descomprimit i cada element que conté instal·lat en el lloc Web. Els fitxers que llavors seran instal·lat en el lloc Web són:',
	'upload_zip_telquel' => 'instal·lat tal qual, com a arxiu comprimit Zip;',
	'upload_zip_titrer' => 'Titular segons el nom dels fitxers'
);
